package glob
import "github.com/gobwas/glob"
Index ¶
Functions ¶
func QuoteMeta ¶
QuoteMeta returns a string that quotes all glob pattern meta characters inside the argument text; For example, QuoteMeta(`{foo*}`) returns `\[foo\*\]`.
Types ¶
type Glob ¶
Glob represents compiled glob pattern.
func Compile ¶
Compile creates Glob for given pattern and strings (if any present after pattern) as separators. The pattern syntax is:
pattern:
{ term }
term:
`*` matches any sequence of non-separator characters
`**` matches any sequence of characters
`?` matches any single non-separator character
`[` [ `!` ] { character-range } `]`
character class (must be non-empty)
`{` pattern-list `}`
pattern alternatives
c matches character c (c != `*`, `**`, `?`, `\`, `[`, `{`, `}`)
`\` c matches character c
character-range:
c matches character c (c != `\\`, `-`, `]`)
`\` c matches character c
lo `-` hi matches character c for lo <= c <= hi
pattern-list:
pattern { `,` pattern }
comma-separated (without spaces) patterns
func MustCompile ¶
MustCompile is the same as Compile, except that if Compile returns error, this will panic
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| cmd | |
| cmd/globdraw | |
| cmd/globtest | |
| compiler | |
| match | |
| match/debug | |
| syntax | |
| syntax/ast | |
| syntax/lexer | |
| util | |
| util/runes | |
| util/strings |
- Version
- v0.2.3 (latest)
- Published
- Feb 8, 2018
- Platform
- linux/amd64
- Imports
- 2 packages
- Last checked
- 1 year ago –
Tools for package owners.